Improve this Doc

# Error: $resource:badcfg
Response does not match configured parameter

    Error in resource configuration for action `{0}`. Expected response to contain an {1} but got an {2} (Request: {3} {4})

## Description

This error occurs when the `$resource` service expects a response that can be deserialized as an array but receives an object, or vice versa. By default, all resource actions expect objects, except `query` which expects arrays.

To resolve this error, make sure your `$resource` configuration matches the actual format of the data returned from the server.

For more information, see the `$resource` API reference documentation.